@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Dict
 
 from rb.core.block import Block
 from rb.core.lang import Lang
@@ -14,38 +14,36 @@ logger = Logger.get_logger()
 
 SIGNIFICANT_LIMIT = 5
 
+
 class Contribution(TextElement):
 
-    def __init__(self, lang: Lang, text: str,
-        participant: Participant,
-        parent_contribution: "Contribution",
-        timestamp: int,
-        depth: int = TextElementType.BLOCK.value,
-        container: TextElement = None,
-        ):
-        
+    def __init__(self, lang: Lang, text: str, participant: Participant,
+                 parent_contribution: "Contribution", contribution_raw: Dict,
+                 timestamp: int, depth: int = TextElementType.BLOCK.value,
+                 container: TextElement = None):
         super().__init__(lang=lang, text=text, depth=depth, container=container)
         self.parent_contribution = parent_contribution
         self.participant = participant
         self.timestamp = timestamp
 
+        # used for creating per-participant conversations, based on original contributions
+        self.contribution_raw = contribution_raw
 
     def add_sentence(self, sentence: Sentence):
         self.components.append(sentence)
         sentence.container = self
 
     def get_parent(self) -> "Contribution":
-    	return self.parent_contribution
+        return self.parent_contribution
 
     def get_participant(self) -> Participant:
         return self.participant
 
     def get_timestamp(self) -> int:
-    	return self.timestamp
+        return self.timestamp
 
     def is_significant(self):
         return len(self.get_words()) >= SIGNIFICANT_LIMIT
 
-    def __str__(self):
-        return NotImplemented
-
+    def get_raw_contribution(self) -> "Contribution":
+        return self.contribution_raw
